@@ -23,47 +23,54 @@ extern int optind;
 static void
 usage(void)
 {
-        fprintf(stderr, "usage: nsd-patch [options]\n");
-        fprintf(stderr, "       Reads database and ixfrs and patches up zone files.\n");
-	fprintf(stderr, "       Version %s. Report bugs to <%s>.\n\n", 
-		PACKAGE_VERSION, PACKAGE_BUGREPORT);
-        fprintf(stderr, "-c configfile	Specify config file to use, instead of %s\n", CONFIGFILE);
-        fprintf(stderr, "-f		Force writing of zone files.\n");
-        fprintf(stderr, "-h		Print this help information.\n");
-        fprintf(stderr, "-l		List contents of transfer journal difffile, %s\n",
-		DIFFFILE);
-        fprintf(stderr, "-x difffile	Specify diff file to use, instead of diff file from config.\n");
-        exit(1);
+	fprintf(stderr, "usage: nsd-patch [options]\n");
+	fprintf(stderr, "       Reads database and ixfrs and patches up zone files.\n");
+	fprintf(stderr, "       Version %s. Report bugs to <%s>.\n\n", PACKAGE_VERSION, PACKAGE_BUGREPORT);
+	fprintf(stderr, "-c configfile	Specify config file to use, instead of %s\n", CONFIGFILE);
+	fprintf(stderr, "-f		Force writing of zone files.\n");
+	fprintf(stderr, "-h		Print this help information.\n");
+	fprintf(stderr, "-l		List contents of transfer journal difffile, %s\n", DIFFFILE);
+	fprintf(stderr, "-o dbfile	Specify dbfile to output the result "
+			"directly to dbfile, nsd.db.\n");
+	fprintf(stderr, "-s		Skip writing of zone files.\n");
+	fprintf(stderr, "-x difffile	Specify diff file to use, instead of diff file from config.\n");
+	exit(1);
 }
 
 static void
 list_xfr(FILE *in)
 {
+	uint32_t timestamp[2];
 	uint32_t skiplen, len, new_serial;
 	char zone_name[3072];
 	uint16_t id;
 	uint32_t seq_nr, len2;
 
-	if(!diff_read_32(in, &len) ||
+	if(!diff_read_32(in, &timestamp[0]) ||
+		!diff_read_32(in, &timestamp[1]) ||
+		!diff_read_32(in, &len) ||
 		!diff_read_str(in, zone_name, sizeof(zone_name)) ||
 		!diff_read_32(in, &new_serial) ||
 		!diff_read_16(in, &id) ||
 		!diff_read_32(in, &seq_nr)) {
-		printf("incomplete zone transfer content packet\n");
+		fprintf(stderr, "incomplete zone transfer content packet\n");
 		return;
 	}
 	skiplen = len - (sizeof(uint32_t)*3 + sizeof(uint16_t) + strlen(zone_name));
-	printf("zone %s transfer id %x serial %d: seq_nr %d of %d bytes\n",
-		zone_name, id, new_serial, seq_nr, skiplen);
-	
+	fprintf(stdout, "zone %s transfer id %x serial %u timestamp %u.%u: "
+			"seq_nr %d of %d bytes\n", zone_name, id, new_serial,
+		timestamp[0], timestamp[1], seq_nr, skiplen);
+
 	if(fseeko(in, skiplen, SEEK_CUR) == -1)
 		fprintf(stderr, "fseek failed: %s\n", strerror(errno));
+
 	if(!diff_read_32(in, &len2)) {
-		printf("incomplete zone transfer content packet\n");
+		fprintf(stderr, "incomplete zone transfer content packet\n");
 		return;
 	}
 	if(len != len2) {
-		printf("Packet seq %d had bad length check bytes!\n", seq_nr);
+		fprintf(stderr, "packet seq %d had bad length check bytes!\n",
+			seq_nr);
 	}
 }
 
@@ -87,6 +94,7 @@ get_date(const char* log)
 static void
 list_commit(FILE *in)
 {
+	uint32_t timestamp[2];
 	uint32_t len;
 	char zone_name[3072];
 	uint32_t old_serial, new_serial;
@@ -96,7 +104,9 @@ list_commit(FILE *in)
 	char log_msg[10240];
 	uint32_t len2;
 
-	if(!diff_read_32(in, &len) ||
+	if(!diff_read_32(in, &timestamp[0]) ||
+		!diff_read_32(in, &timestamp[1]) ||
+		!diff_read_32(in, &len) ||
 		!diff_read_str(in, zone_name, sizeof(zone_name)) ||
 		!diff_read_32(in, &old_serial) ||
 		!diff_read_32(in, &new_serial) ||
@@ -105,15 +115,16 @@ list_commit(FILE *in)
 		!diff_read_8(in, &commit) ||
 		!diff_read_str(in, log_msg, sizeof(log_msg)) ||
 		!diff_read_32(in, &len2)) {
-		printf("incomplete commit/rollback packet\n");
+		fprintf(stderr, "incomplete commit/rollback packet\n");
 		return;
 	}
-	printf("zone %s transfer id %x serial %d: %s of %d packets\n",
+	fprintf(stdout, "zone %s transfer id %x serial %d: %s of %d packets\n",
 		zone_name, id, new_serial, commit?"commit":"rollback", num);
-	printf("   time %s, from serial %d, log message: %s\n", 
+	fprintf(stdout, "   time %s, from serial %d, log message: %s\n",
 		get_date(log_msg), old_serial, log_msg);
 	if(len != len2) {
-		printf("  commit packet with bad length check bytes!\n");
+		fprintf(stderr, "  commit packet with bad length check \
+			bytes!\n");
 	}
 }
 
@@ -123,10 +134,11 @@ debug_list(struct nsd_options* opt)
 	const char* file = opt->difffile;
 	FILE *f;
 	uint32_t type;
-	printf("Debug listing of the contents of %s\n", file);
+	fprintf(stdout, "debug listing of the contents of %s\n", file);
 	f = fopen(file, "r");
 	if(!f) {
-		printf("Error opening %s: %s\n", file, strerror(errno));
+		fprintf(stderr, "error opening %s: %s\n", file,
+			strerror(errno));
 		return;
 	}
 	while(diff_read_32(f, &type)) {
@@ -138,7 +150,7 @@ debug_list(struct nsd_options* opt)
 			list_commit(f);
 			break;
 		default:
-			printf("bad part of type %x\n", type);
+			fprintf(stderr, "bad part of type %x\n", type);
 			break;
 		}
 	}
@@ -174,7 +186,7 @@ print_rrs(FILE* out, struct zone* zone)
 	/* first print the SOA record for the zone */
 	if(zone->soa_rrset) {
 		size_t i;
-		for(i=0; i<zone->soa_rrset->rr_count; i++) {
+		for(i=0; i < zone->soa_rrset->rr_count; i++) {
 			if(!print_rr(out, state, &zone->soa_rrset->rrs[i])){
 				fprintf(stderr, "There was an error "
 				   "printing SOARR to zone %s\n",
@@ -191,7 +203,7 @@ print_rrs(FILE* out, struct zone* zone)
 			size_t i;
 			if(rrset->zone != zone || rrset == zone->soa_rrset)
 				continue;
-			for(i=0; i<rrset->rr_count; i++) {
+			for(i=0; i < rrset->rr_count; i++) {
 				if(!print_rr(out, state, &rrset->rrs[i])){
 					fprintf(stderr, "There was an error "
 					   "printing RR to zone %s\n",
@@ -231,7 +243,8 @@ write_to_zonefile(struct zone* zone, struct diff_log* commit_log)
 	time_t now = time(0);
 	FILE *out;
 
-	printf("writing zone %s to file %s\n", zone->opts->name, filename);
+	fprintf(stderr, "writing zone %s to file %s\n", zone->opts->name,
+		filename);
 
 	if(!zone->apex) {
 		fprintf(stderr, "zone %s has no apex, no data.\n", filename);
@@ -244,10 +257,10 @@ write_to_zonefile(struct zone* zone, struct diff_log* commit_log)
 			filename, strerror(errno));
 		return;
 	}
-	
+
 	/* print zone header */
 	fprintf(out, "; NSD version %s\n", PACKAGE_VERSION);
-	fprintf(out, "; nsd-patch zone %s run at time %s", 
+	fprintf(out, "; nsd-patch zone %s run at time %s",
 		zone->opts->name, ctime(&now));
 	print_commit_log(out, domain_dname(zone->apex), commit_log);
 
@@ -261,16 +274,20 @@ int main(int argc, char* argv[])
 	int c;
 	const char* configfile = CONFIGFILE;
 	const char* difffile = NULL;
+	const char* dbfile = NULL;
 	nsd_options_t *options;
-	struct namedb* db;
+	struct namedb* db = NULL;
+	struct namedb* dbout = NULL;
 	struct zone* zone;
 	struct diff_log* commit_log = 0;
 	size_t fake_child_count = 1;
 	int debug_list_diff = 0;
 	int force_write = 0;
+	int skip_write = 0;
+	int difffile_exists = 0;
 
         /* Parse the command line... */
-	while ((c = getopt(argc, argv, "c:fhlx:")) != -1) {
+	while ((c = getopt(argc, argv, "c:fhlo:sx:")) != -1) {
 	switch (c) {
 		case 'c':
 			configfile = optarg;
@@ -279,7 +296,27 @@ int main(int argc, char* argv[])
 			debug_list_diff = 1;
 			break;
 		case 'f':
-			force_write = 1;
+			if (skip_write)
+			{
+				fprintf(stderr, "Cannot force and skip writing "
+						"zonefiles at the same time\n");
+				exit(1);
+			}
+			else
+				force_write = 1;
+			break;
+		case 's':
+			if (force_write)
+			{
+				fprintf(stderr, "Cannot skip and force writing "
+						"zonefiles at the same time\n");
+				exit(1);
+			}
+			else
+				skip_write = 1;
+			break;
+		case 'o':
+			dbfile = optarg;
 			break;
 		case 'x':
 			difffile = optarg;
@@ -291,7 +328,7 @@ int main(int argc, char* argv[])
 	}
 	argc -= optind;
 	argv += optind;
-	if (argc != 0) 
+	if (argc != 0)
 		usage();
 
 	/* read config file */
@@ -303,21 +340,23 @@ int main(int argc, char* argv[])
 	}
 	if(options->zonesdir && options->zonesdir[0]) {
 		if (chdir(options->zonesdir)) {
-			fprintf(stderr, "nsd-patch: cannot chdir to %s: %s\n", 
+			fprintf(stderr, "nsd-patch: cannot chdir to %s: %s\n",
 				options->zonesdir, strerror(errno));
 			exit(1);
 		}
 	}
 
 	/* override difffile if commandline option given */
-	if(difffile) 
-		options->difffile = difffile; 
+	if(difffile)
+		options->difffile = difffile;
 
 	/* see if necessary */
 	if(!exist_difffile(options)) {
-		printf("No diff file, nothing to do.\n");
-		exit(0);
+		fprintf(stderr, "No diff file.\n");
+		if (!force_write)
+			exit(0);
 	}
+	else	difffile_exists = 1;
 
 	if(debug_list_diff) {
 		debug_list(options);
@@ -325,10 +364,10 @@ int main(int argc, char* argv[])
 	}
 
 	/* read database and diff file */
-	printf("reading database\n");
+	fprintf(stdout, "reading database\n");
 	db = namedb_open(options->database, options, fake_child_count);
 	if(!db) {
-		fprintf(stderr, "Could not read database: %s\n", 
+		fprintf(stderr, "could not read database: %s\n",
 			options->database);
 		exit(1);
 	}
@@ -339,26 +378,52 @@ int main(int argc, char* argv[])
 		zone->updated = 0;
 	}
 
-	/* read ixfr diff file */
-	printf("reading updates to database\n");
-	if(!diff_read_file(db, options, &commit_log, fake_child_count)) {
-		fprintf(stderr, "unable to load the diff file: %s\n", 
-			options->difffile);
-		exit(1);
+	if (dbfile)
+		dbout = namedb_new(dbfile);
+	if (dbout)
+	{
+		db->fd = dbout->fd;
+		db->filename = (char*) dbfile;
 	}
 
-	printf("writing changed zones\n");
-	for(zone = db->zones; zone; zone = zone->next)
-	{
-		if(!force_write && !zone->updated) {
-			printf("zone %s had not changed.\n",
-				zone->opts->name);
-			continue;
+	/* read ixfr diff file */
+	if (difffile_exists) {
+		fprintf(stdout, "reading updates to database\n");
+		if(!diff_read_file(db, options, &commit_log, fake_child_count))
+		{
+			fprintf(stderr, "unable to load the diff file: %s\n",
+				options->difffile);
+			exit(1);
 		}
-		/* write zone to its zone file */
-		write_to_zonefile(zone, commit_log);
 	}
-	printf("done\n");
+
+	if (skip_write)
+		fprintf(stderr, "skip patching up zonefiles.\n");
+	else {
+		fprintf(stdout, "writing changed zones\n");
+		for(zone = db->zones; zone; zone = zone->next)
+		{
+			if(!force_write && !zone->updated) {
+				fprintf(stdout, "zone %s had not changed.\n",
+					zone->opts->name);
+				continue;
+			}
+			/* write zone to its zone file */
+			write_to_zonefile(zone, commit_log);
+		}
+	}
+
+	/* output result directly to dbfile */
+	if (dbout)
+	{
+		fprintf(stdout, "storing database to %s.\n", dbout->filename);
+	        if (namedb_save(db) != 0) {
+			fprintf(stderr, "error writing the database (%s): %s\n",
+				dbfile, strerror(errno));
+			exit(1);
+		}
+	}
+	fprintf(stdout, "done\n");
 
 	return 0;
 }
