@@ -21,8 +21,6 @@ struct region;
 struct dname;
 struct acl_options;
 
-#define XFRD_TCP_TIMEOUT TCP_TIMEOUT /* seconds */
-
 typedef struct xfrd_tcp xfrd_tcp_t;
 typedef struct xfrd_tcp_set xfrd_tcp_set_t;
 /*
@@ -33,6 +31,8 @@ struct xfrd_tcp_set {
 	struct xfrd_tcp *tcp_state[XFRD_MAX_TCP];
 	/* number of TCP connections in use. */
 	int tcp_count;
+	/* TCP timeout. */
+	int tcp_timeout;
 	/* linked list of zones waiting for a TCP connection */
 	struct xfrd_zone *tcp_waiting_first, *tcp_waiting_last;
 };
@@ -82,11 +82,11 @@ void xfrd_tcp_write(xfrd_tcp_set_t* set, struct xfrd_zone* zone);
 /* see if the tcp connection is in the reading stage (else writin) */
 static inline int xfrd_tcp_is_reading(xfrd_tcp_set_t* set, int conn)
 {return set->tcp_state[conn]->is_reading;}
-/* 
+/*
  * Read from a stream connection (size16)+packet into buffer.
  * returns value is
- *	-1 on error. 
- *	0 on short read, call back later. 
+ *	-1 on error.
+ *	0 on short read, call back later.
  *	1 on completed read.
  * On first call, make sure total_bytes = 0, msglen=0, buffer_clear().
  * and the packet and fd need to be set.
@@ -96,7 +96,7 @@ int conn_read(xfrd_tcp_t* conn);
  * Write to a stream connection (size16)+packet.
  * return value is
  * -1 on error. 0 on short write, call back later. 1 completed write.
- * On first call, make sure total_bytes=0, msglen=buffer_limit(), 
+ * On first call, make sure total_bytes=0, msglen=buffer_limit(),
  * buffer_flipped(). packet and fd need to be set.
  */
 int conn_write(xfrd_tcp_t* conn);
@@ -108,11 +108,18 @@ void xfrd_setup_packet(struct buffer* packet,
 void xfrd_write_soa_buffer(struct buffer* packet,
         const struct dname* apex, struct xfrd_soa* soa);
 /* use acl address to setup sockaddr struct, returns length of addr. */
-socklen_t xfrd_acl_sockaddr(struct acl_options* acl, 
+socklen_t xfrd_acl_sockaddr_to(struct acl_options* acl,
 #ifdef INET6
 	struct sockaddr_storage *to);
 #else
 	struct sockaddr_in *to);
 #endif /* INET6 */
 
+socklen_t xfrd_acl_sockaddr_frm(struct acl_options* acl,
+#ifdef INET6
+	struct sockaddr_storage *frm);
+#else
+	struct sockaddr_in *frm);
+#endif /* INET6 */
+
 #endif /* XFRD_TCP_H */
